from django.db import models
from users.models import User
from django_resized import ResizedImageField
# Create your models here.

class Categories (models.Model):
    name = models.CharField(max_length=200)

    def __str__(self):
        return self.name

class Post(models.Model):
    category = models.ForeignKey(Categories, related_name='posts', on_delete=models.CASCADE)
    title = models.CharField(max_length=250)
    subtitle = models.CharField(max_length=250, blank=True, null=True)
    datetime = models.DateTimeField(auto_now=True)
    modified = models.DateTimeField(auto_now_add=True)
    content = models.TextField(null=True)
    image = models.ImageField(upload_to='posts/', null=True)
    author = models.CharField(max_length=200)

    @property
    def imageURL(self):
        try:
            url = self.image.url
        except:
            url = ''
        print('URL', url)
        return url

    def __str__(self):
        return self.title + " " + self.author

class Testimonial(models.Model):
    noms = models.CharField(max_length=200)
    category = models.CharField(max_length=200)
    content = models.TextField(null=True)
    image = models.ImageField(upload_to='posts/', null=True, default='fofat.png')
    date = models.DateTimeField(auto_now=True)

    @property
    def imageURL(self):
        try:
            url = self.image.url
        except:
            url = ''
        print('URL', url)
        return url

    def __str__(self):
        return self.noms + " " + self.category

class Album(models.Model):
    title = models.CharField(max_length=200)
    datetime = models.DateTimeField(auto_now_add=True)
    image = ResizedImageField(size=[570, 380], upload_to='album/', blank=True, null=True)
    imagexl = ResizedImageField(size=[1280, 800], upload_to='album/', blank=True, null=True)

    @property
    def imageURL(self):
        try:
            url = self.image.url
        except:
            url = ''
        print('URL', url)
        return url

    @property
    def imageURL2(self):
        try:
            url = self.imagexl.url
        except:
            url = ''
        print('URL', url)
        return url

    def __str__(self):
        return self.title

class Partner(models.Model):
    title = models.CharField(max_length=200)
    datetime = models.DateTimeField(auto_now_add=True)
    image = ResizedImageField(size=[300, 100], upload_to='album/', blank=True, null=True)

    @property
    def imageURL(self):
        try:
            url = self.image.url
        except:
            url = ''
        print('URL', url)
        return url

    def __str__(self):
        return self.title

class Category(models.Model):
    name = models.CharField(max_length=100)

    def __str__(self):
        return self.name

class News(models.Model):
    title = models.CharField(max_length=200)
    content = models.TextField()
    published_date = models.DateTimeField(auto_now_add=True)
    categories = models.ForeignKey(Category, related_name='news', on_delete=models.CASCADE, null=True)
    image = ResizedImageField(size=[750, 410], upload_to='news/', blank=True, null=True)

    @property
    def imageURL(self):
        try:
            url = self.image.url
        except:
            url = ''
        print('URL', url)
        return url

    def __str__(self):
        return self.title

class Subscriber(models.Model):
    email = models.EmailField(unique=True)
    subscribed = models.BooleanField(default=True)

    def __str__(self):
        return self.email